<?php
/**
 * Blogstart functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package blogstart
 */

if ( ! function_exists( 'blogstart_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function blogstart_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on blogstart, use a find and replace
		 * to change 'blogstart' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'blogstart', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'blogstart-popular-post', 85, 70, true );
		add_image_size( 'blogstart-sm-gallery-post', 90, 90, true );
		add_image_size( 'blogstart-post-slider', 270, 300, true );
		add_image_size( 'blogstart-thumbnail', 385, 300, true );
		add_image_size( 'blogstart-fthumbnail', 370, 260, true );
		add_image_size( 'blogstart-flthumnail', 770, 590, true );
		add_image_size( 'blogstart-fslider', 270, 150, true );
		add_image_size( 'blogstart-related', 250, 170, true );
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'blogstart' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/*
		 * Post Formats Support
		 */
		add_theme_support(
			'post-formats',
			array(
				'gallery',
				'image',
				'quote',
				'video',
			)
		);

		// Set up the WordPress core custom background feature.
		$custombgargs = apply_filters(
			'blogstart_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		);
		add_theme_support( 'custom-background', $custombgargs );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
		add_editor_style( array( 'assets/stylesheets/vendor/resources/bootstrap.css' ) );
	}
endif;
add_action( 'after_setup_theme', 'blogstart_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blogstart_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'blogstart_content_width', 640 );
}
add_action( 'after_setup_theme', 'blogstart_content_width', 0 );

/**
 * BlogStart Custom Widgets
 */
require get_template_directory() . '/inc/widgets.php';

/**
 * Blogstart Register Sidebar
 */
require get_template_directory() . '/inc/register-sidebar.php';

/**
 * Blogstart all scripts files
 */
require get_template_directory() . '/inc/script-files.php';

/**
 * Blogstart Comment Form
 */
require get_template_directory() . '/inc/comment-form.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */

require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */

if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/*update to pro link*/
require get_template_directory() . '/blogstartpro/class-customize.php';

/*Notice*/
require  get_template_directory() . '/inc/blogstart-details.php';

function blogstart_excerpt_length( $length ) {
    return 20;
}
add_filter( 'excerpt_length', 'blogstart_excerpt_length', 999 );
